@@ -146,6 +146,7 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 				GTK_STOCK_SAVE, GTK_RESPONSE_YES, NULL);
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (dlg), GTK_RESPONSE_YES);
+	atk_object_set_role (gtk_widget_get_accessible (GTK_WIDGET (dlg)), ATK_ROLE_ALERT);
 }
 
 static void 
@@ -636,9 +637,13 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
 
-	str = g_strdup_printf (_("There are %d documents with unsaved changes. "
-				 "Save changes before closing?"),
-			       g_slist_length (priv->unsaved_documents));
+	str = g_strdup_printf (
+			ngettext ("There is %d document with unsaved changes. "
+				  "Save changes before closing?",
+				  "There are %d documents with unsaved changes. "
+				  "Save changes before closing?",
+				  g_slist_length (priv->unsaved_documents)),
+			g_slist_length (priv->unsaved_documents));
 	
 	markup_str = g_strconcat ("<span weight=\"bold\" size=\"larger\">", str, "</span>", NULL);
 	g_free (str);
